@@ -1,8 +1,8 @@
 import random
 
-from scaled.client.client import Client
+from scaled.client import Client
 from scaled.cluster.combo import SchedulerClusterCombo
-from scaled.utility.zmq_config import ZMQConfig, ZMQType
+
 from scaled.utility.logging.scoped_logger import ScopedLogger
 from scaled.utility.logging.utility import setup_logger
 
@@ -13,23 +13,26 @@ def sleep_print(sec: int):
 
 def main():
     setup_logger()
-    config = ZMQConfig(type=ZMQType.tcp, host="127.0.0.1", port=2345)
 
-    cluster = SchedulerClusterCombo(address=config, n_workers=10, event_loop="uvloop")
-    client = Client(config=config)
+    address = "tcp://127.0.0.1:2345"
 
-    tasks = [random.randint(0, 100) for _ in range(100000)]
+    cluster = SchedulerClusterCombo(
+        address=address, n_workers=10, per_worker_queue_size=2, event_loop="uvloop"
+    )
+    client = Client(address=address)
 
-    with ScopedLogger(f"submit {len(tasks)} tasks"):
+    tasks = [random.randint(0, 101) for _ in range(10000)]
+
+    with ScopedLogger(f"scaled submit {len(tasks)} tasks"):
         futures = [client.submit(sleep_print, i) for i in tasks]
 
-    with ScopedLogger(f"gather {len(futures)} results"):
+    with ScopedLogger(f"scaled gather {len(futures)} results"):
         results = [future.result() for future in futures]
 
     assert results == tasks
 
-    cluster.shutdown()
     client.disconnect()
+    cluster.shutdown()
 
 
 if __name__ == "__main__":
